@@ -134,10 +134,9 @@
  *
  ******************************************************************************/
 
-#define SkIsrRetVar     void
-#define SkIsrRetNone    NULL
-#define SkIsrRetHandled NULL
-
+#define SkIsrRetVar     irqreturn_t
+#define SkIsrRetNone    IRQ_NONE
+#define SkIsrRetHandled IRQ_HANDLED
 #define DEV_KFREE_SKB(skb) dev_kfree_skb(skb)
 #define DEV_KFREE_SKB_IRQ(skb) dev_kfree_skb_irq(skb)
 #define DEV_KFREE_SKB_ANY(skb) dev_kfree_skb_any(skb)
@@ -257,7 +256,7 @@ struct s_DrvRlmtMbuf {
 
 typedef struct s_IOCTL SK_GE_IOCTL;
 struct s_IOCTL {
-	char*		pData;
+	char __user *	pData;
 	unsigned int	Len;
 };
 
@@ -729,6 +728,9 @@ struct s_DevNet {
 	struct 		timer_list LLCTimer;	/* LLC timer struct  */
 	struct 		timer_list WakeupTimer;	/* Wakeup packet timer struct  */
 #endif
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,23)
+	struct		napi_struct napi;	/* NAPI structure */
+#endif
 };  
 
 /*******************************************************************************
