@@ -95,7 +95,7 @@ function unpack_driver ()
 	tar xfv $drv_name.tar >> $logfile
 	cd ..
 
-	if [ -f ${TMP_DIR}/2.4/skge.c ]; then
+	if [ -f ${TMP_DIR}/2.6/skge.c ]; then
 		echo -en "\015"
 		echo -n $fname
 		message_status 1 "done"
@@ -137,147 +137,10 @@ function help ()
 	exit
 }
 
-#################################################################
-# Kernel 2.4 make functions
-#################################################################
-function create_makefile_24 ()
+function create_makefile ()
 {
-	# Create makefile (kernel 2.4 version)
-	# Syntax: create_makefile_24
-	# Author: mlindner
-	# Returns:
-	#       N/A
-
-	if [ $IPMI_SUPPORT == "1" ]; then
-		ipmi_oflags=`echo skgeasf.o skgeasfconv.o skgespi.o skgespilole.o skfops.o`;
-		ipmi_cflags=`echo skgeasf.c skgeasfconv.c skgespi.c skgespilole.c skfops.c`;
-		ipmi_flag=`echo -DSK_ASF`
-	else
-		if [ $DASH_SUPPORT == "1" ]; then
-			ipmi_oflags=`echo skgeasf.o skgeasfconv.o skgespi.o skgespilole.o skfops.o`;
-			ipmi_cflags=`echo skgeasf.c skgeasfconv.c skgespi.c skgespilole.c skfops.c`;
-			ipmi_flag=`echo -DSK_ASF -DUSE_ASF_DASH_FW`
-		else
-			ipmi_oflags=""
-			ipmi_cflags=""
-			ipmi_flag=""
-		fi
-	fi
-
-	if [ $1 == "1" ]; then
-	{
-	echo '# Makefile for Marvell Yukon/SysKonnect SK-98xx/SK-95xx Gigabit'
-	echo '# Ethernet Adapter driver'
-	echo ''
-	echo '# just to get the CONFIG_SMP and CONFIG_MODVERSIONS defines:'
-	echo 'ifeq ($(KERNEL_SOURCE)/.config, $(wildcard $(KERNEL_SOURCE)/.config))'
-	echo 'include $(KERNEL_SOURCE)/.config'
-	echo 'endif'
-	echo 'SYSINC =  -I$(KERNEL_HEADER) -I.'
-	echo 'SYSDEF = -DLINUX -D__KERNEL__'
-	echo 'ifdef CONFIG_SMP'
-	echo 'SYSDEF += -D__SMP__'
-	echo 'endif'
-	echo 'SRCDEF = -DMODULE -O2 -DGENESIS -DSK_DIAG_SUPPORT -DSK_USE_CSUM \'
-	echo '         -DYUKON -DYUK2 -DSK_EXTREME  -DCONFIG_SK98LIN_ZEROCOPY ${ipmi_flag}'
-	echo 'ifdef CONFIG_MODVERSIONS'
-	echo 'SRCDEF += -DMODVERSIONS -include $(KERNEL_HEADER)/linux/modversions.h'
-	echo 'SRCDEF += -include $(KERNEL_HEADER)/config/modversions.h '
-	echo 'endif'
-	echo 'USERDEF='
-	echo 'WARNDEF=-Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts \'
-	echo '	   -Wparentheses -Wpointer-arith -Wcast-qual -Wno-multichar  \'
-	echo '	   -Wno-cast-qual $(MCMODEL)'
-	echo 'INCLUDE= $(SYSINC)'
-	echo 'DEFINES=  $(SYSDEF) $(SRCDEF) $(USERDEF) $(WARNDEF)'
-	echo 'SRCFILES = skge.c kgeinit.c skgesirq.c skxmac2.c skvpd.c skgehwt.c \'
-	echo '	   skqueue.c sktimer.c sktwsi.c sklm80.c skrlmt.c $ipmi_cflags skgepnmi.c \'
-	echo '	   skaddr.c skcsum.c skproc.c skdim.c sky2.c skethtool.c sky2le.c'
-	echo 'OBJECTS =  skge.o skaddr.o skgehwt.o skgeinit.o skgepnmi.o skgesirq.o \'
-	echo '	   sktwsi.o sklm80.o skqueue.o skrlmt.o sktimer.o skvpd.o skdim.o\'
-	echo '	   skxmac2.o skcsum.o skproc.o sky2.o skethtool.o ${ipmi_oflags} sky2le.o'
-	echo 'DRVBIN = sk98lin.o'
-	echo 'LD	= ld'
-	echo "CC	= $GCCNAME"
-	echo 'CFLAGS	= $(INCLUDE) $(DEFINES)'
-	echo 'FILES	= $(SRCFILES) makefile'
-	echo 'TARGETS	= $(DRVBIN)'
-	echo '.c.o:   $<'
-	echo '	$(CC) $(CFLAGS) -c $<'
-	echo 'all:  $(OBJECTS)'
-	echo '	$(LD) -r -o $(DRVBIN) $(OBJECTS)'
-	echo 'clean:'
-	echo '	rm *.o'
-	echo '*.o: \'
-	echo '	h/*.h'
-	} &> ${TMP_DIR}/all/Makefile
-	else
-	cp ${TMP_DIR}/2.4/Makefile ${TMP_DIR}/all/Makefile
-	fi
-}
-
-function make_driver_24 ()
-{
-	# Configure, check and build the driver (kernel 2.4)
-	# Syntax: make_driver
-	# Author: mlindner
-	# Returns:
-	#       N/A
-
-	# Compile the driver
-	echo >> $logfile 2>&1 
-	echo "+++ Compile the driver" >> $logfile 2>&1
-	echo "+++ ====================================" >> $logfile 2>&1
-	cd ${TMP_DIR}/all
-
-	fname="Compile the driver"
-	echo -n $fname
-	message_status 3 "working"
-	make $MAKE_CPU_FLAG >> $logfile 2>&1
-
-
-	if [ ! -f $drv_name.o ]; then
-		echo -en "\015"
-		echo -n $fname
-		message_status 2 "failed"
-
-		make_dep
-		fname="Compile the driver"
-		echo -n $fname
-		message_status 3 "working"
-		make $MAKE_CPU_FLAG >> $logfile 2>&1
-	fi
-
-
-	if [ -f $drv_name.o ]; then
-		cp $drv_name.o ../
-		echo -en "\015"
-		echo -n $fname
-		message_status 1 "done"
-	else
-		echo -en "\015"
-		echo -n $fname
-		message_status 0 "error"
- 		echo
-		echo "An error has occurred during the compile proces which prevented "; \
-		echo "the installation from completing.                              "; \
-		echo "Take a look at the log file install.log for more informations.  "; \
-		echo "+++ Compiler error" >> $logfile 2>&1
-		echo $inst_failed
-		cleanup
-		clean
-		exit 1
-	fi
-}
-
-
-#################################################################
-# Kernel 2.6 make functions
-#################################################################
-function create_makefile_26 ()
-{
-	# Create makefile (kernel 2.6 version)
-	# Syntax: create_makefile_26
+	# Create makefile
+	# Syntax: create_makefile
 	#	1 == change makefile for compilation
 	#	1 != don't change
 	# Author: mlindner
@@ -322,7 +185,7 @@ function create_makefile_26 ()
 
 		addparam="ADDPARAM +=  $addparam"
 		local addparamfirst="# ADDPARAM +=" 
-		sed -e "s$A$addparamfirst$A$addparam$A" \
+			sed -e "s$A$addparamfirst$A$addparam$A" \
 			${TMP_DIR}/all/Makefile \
 			>> ${TMP_DIR}/all/Makefile2
 		cp ${TMP_DIR}/all/Makefile2 ${TMP_DIR}/all/Makefile
@@ -330,9 +193,9 @@ function create_makefile_26 ()
 
 }
 
-function make_driver_26 ()
+function make_driver ()
 {
-	# Configure, check and build the driver (kernel 2.4)
+	# Configure, check and build the driver
 	# Syntax: make_driver
 	# Author: mlindner
 	# Returns:
@@ -608,155 +471,10 @@ function get_patch_infos ()
 	fi
 }
 
-
-function generate_patch_for_help24 ()
+function generate_patch_for_kconfig ()
 {
 	# Generate a patch for the config file
-	# Syntax: generate_patch_for_help24
-	#	package_root, kernel_root
-	# Author: mlindner
-	# Returns:
-	#       N/A
-	fname="Generate Config.help patch"
-	echo -n $fname
-	message_status 3 "working"
-	local packagedir="$1"
-	local kerneldir=$2
-	local startline
-	local totalline
-	local splitline
-	local count=0
-	local splt=0
-	local A="`echo | tr '\012' '\001' `"
-
-	# initial cleanup
-	rm -rf ${TMP_DIR}/all_sources_patch
-
-	# find the first line of the sk block
-	startline=`grep "CONFIG_SK98LIN$" $kerneldir/Documentation/Configure.help -n | cut -d ':' -f 1`
-	totalline=`cat $kerneldir/Documentation/Configure.help | wc -l`
-	((startline=$startline - 2))
-	((splitline=$totalline - $startline))
-	((splitline=$splitline - 2))
-
-	head -n $startline $kerneldir/Documentation/Configure.help > ${TMP_DIR}/Configure.help
-	cat $packagedir/misc/Configure.help >> ${TMP_DIR}/Configure.help
-	tail -n $splitline $kerneldir/Documentation/Configure.help > ${TMP_DIR}/Configuretemp
-
-	# find the end of the block	
-	while read line; do
-		((count=$count + 1))
-		splt=`echo $line | grep CONFIG_ -c`
-		if [ $splt -gt 0 ]; then break; fi
-	done < ${TMP_DIR}/Configuretemp
-	((count=$count - 2))
-	((splitline=$splitline - $count))
-	tail -n $splitline $kerneldir/Documentation/Configure.help >> ${TMP_DIR}/Configure.help
-
-	# Make diff
-	diff -ruN $kerneldir/Documentation/Configure.help ${TMP_DIR}/Configure.help \
-		> ${TMP_DIR}/all_sources_patch
-	replacement="linux-new/Documentation"
-	sed -e "s$A${TMP_DIR}$A$replacement$A" \
-		${TMP_DIR}/all_sources_patch &> ${TMP_DIR}/all_sources_patch2
-	replacement="linux"
-	sed -e "s$A$kerneldir$A$replacement$A" \
-		${TMP_DIR}/all_sources_patch2 &> ${TMP_DIR}/all_sources_patch
-
-
-	# Complete the patch
-	if [ -f ${TMP_DIR}/all_sources_patch ] && \
-		[ `cat ${TMP_DIR}/all_sources_patch | wc -c` -gt 0 ]; then
-		echo "diff -ruN linux/Documentation/Configure.help \
-linux-new/Documentation/Configure.help" >> ${PATCH_NAME}
-		cat ${TMP_DIR}/all_sources_patch >> ${PATCH_NAME}
-	fi
-
-	# Status
-	echo -en "\015"
-	echo -n $fname
-	message_status 1 "done"
-}
-
-
-function generate_patch_for_config24 ()
-{
-	# Generate a patch for the config file
-	# Syntax: generate_patch_for_config
-	#	package_root, kernel_root
-	# Author: mlindner
-	# Returns:
-	#       N/A
-	fname="Generate Config.in patch"
-	echo -n $fname
-	message_status 3 "working"
-	local packagedir="$1"
-	local kerneldir=$2
-	local startline
-	local totalline
-	local splitline
-	local count=0
-	local splt=0
-	local A="`echo | tr '\012' '\001' `"
-
-	# find the first line of the sk block
-	startline=`grep "CONFIG_SK98LIN " $kerneldir/drivers/net/Config.in -n | cut -d ':' -f 1`
-	totalline=`cat $kerneldir/drivers/net/Config.in | wc -l`
-
-
-	((startline=$startline - 1))
-	((splitline=$totalline - $startline))
-	((splitline=$splitline - 1))
-	head -n $startline $kerneldir/drivers/net/Config.in > ${TMP_DIR}/Config.in
-
-	# Insert a new description
-	echo "dep_tristate 'Marvell Yukon Chipset / SysKonnect SK-98xx Support' CONFIG_SK98LIN \$CONFIG_PCI" >> ${TMP_DIR}/Config.in
-	echo 'if [ "$CONFIG_SK98LIN" != "n" ]; then' >> ${TMP_DIR}/Config.in
-	echo "	bool '    Use Rx polling (NAPI)' CONFIG_SK98LIN_NAPI" >> ${TMP_DIR}/Config.in
-	echo "fi" >> ${TMP_DIR}/Config.in
-
-	tail -n $splitline $kerneldir/drivers/net/Config.in > ${TMP_DIR}/Config.intemp
-
-	# find the end of the block	
-	while read line; do
-		((count=$count + 1))
-		splt=`echo $line | grep "^dep_tristate"  -c`
-		if [ $splt -gt 0 ]; then break; fi
-	done < ${TMP_DIR}/Config.intemp
-	((count=$count - 1))
-	((splitline=$splitline - $count))
-	tail -n $splitline $kerneldir/drivers/net/Config.in >> ${TMP_DIR}/Config.in
-
-	# Make diff
-	diff -ruN $kerneldir/drivers/net/Config.in ${TMP_DIR}/Config.in \
-		> ${TMP_DIR}/all_sources_patch
-	replacement="linux-new/drivers/net"
-	sed -e "s$A${TMP_DIR}$A$replacement$A" \
-		${TMP_DIR}/all_sources_patch &> ${TMP_DIR}/all_sources_patch2
-	replacement="linux"
-	sed -e "s$A$kerneldir$A$replacement$A" \
-		${TMP_DIR}/all_sources_patch2 &> ${TMP_DIR}/all_sources_patch
-
-	# Complete the patch
-	if [ -f ${TMP_DIR}/all_sources_patch ] && \
-		[ `cat ${TMP_DIR}/all_sources_patch | wc -c` -gt 0 ]; then
-		echo "diff -ruN linux/drivers/net/Config.in \
-linux-new/drivers/net/Config.in" >> ${PATCH_NAME}
-		cat ${TMP_DIR}/all_sources_patch >> ${PATCH_NAME}
-	fi
-
-
-	# Status
-	echo -en "\015"
-	echo -n $fname
-	message_status 1 "done"
-}
-
-
-function generate_patch_for_kconfig26 ()
-{
-	# Generate a patch for the config file (kernel 2.6.x)
-	# Syntax: generate_patch_for_kconfig26
+	# Syntax: generate_patch_for_kconfig
 	#	package_root, kernel_root
 	# Author: mlindner
 	# Returns:
@@ -843,8 +561,9 @@ function generate_patch_for_readme ()
 	replacement="linux-new/drivers/net/sk98lin"
 	sed -e "s$A$packagedir$A$replacement$A" \
 		${TMP_DIR}/all_sources_patch &> ${TMP_DIR}/all_sources_patch2
-	replacement="linux"
-	sed -e "s$A$kerneldir$A$replacement$A" \
+	replacement="linux/"
+	nkerneldir="$kerneldir/"
+	sed -e "s$A$nkerneldir$A$replacement$A" \
 		${TMP_DIR}/all_sources_patch2 &> ${TMP_DIR}/all_sources_patch
 
 
@@ -941,8 +660,7 @@ function patch_generation ()
 	cp -pr ${TMP_DIR}/${KERNEL_FAMILY}/* ${TMP_DIR}/all
 
 	# Create makefile
-	[ $KERNEL_FAMILY == "2.4" ] && create_makefile_24 0
-	[ $KERNEL_FAMILY == "2.6" ] && create_makefile_26 0
+	create_makefile 0
 	clear
 
 	# Generate a patch for a specific kernel version
@@ -952,17 +670,7 @@ function patch_generation ()
 	generate_patch_for_readme ${TMP_DIR} $KERNEL_SOURCE
 
 	# Generate a patch for the config file
-	if [ "${KERNEL_FAMILY}" == "2.4" ]; then
-		generate_patch_for_config24 ${TMP_DIR} $KERNEL_SOURCE
-	else
-		generate_patch_for_kconfig26 ${TMP_DIR} $KERNEL_SOURCE
-	fi
-
-	# Generate a patch for the config file
-	if [ "${KERNEL_FAMILY}" == "2.4" ]; then
-		generate_patch_for_help24 ${TMP_DIR} $KERNEL_SOURCE
-	fi
-
+	generate_patch_for_kconfig ${TMP_DIR} $KERNEL_SOURCE
 
 	# Clear the tmp dirs
 	clean
@@ -1111,6 +819,7 @@ function main_global ()
 	# Run given functions
 	if [ "${OPTION_HELP}" ]; then help; fi
 	if [ "${OPTION_SILENT}" ]; then user_sel=`echo user`; fi
+	if [ "${OPTION_LOG}" ]; then print_comp_resources; exit 0; fi
 	if [ "${OPTION_CLEANUP}" ]; then clean; exit 0; fi
 	if [ "${OPTION_PATCH}" ]; then
 		INSTALL_MODE="PATCH"
@@ -1123,6 +832,9 @@ function main_global ()
 		fi
 	fi
 
+	# Delete log file
+	rm -rf $logfile &> /dev/null
+
 	# Print copyright informations, mode selection and check
 	start_sequence
 
@@ -1151,8 +863,7 @@ function main_global ()
 	install_firmware
 
 	# Create makefile
-	[ $KERNEL_FAMILY == "2.4" ] && create_makefile_24 1
-	[ $KERNEL_FAMILY == "2.6" ] && create_makefile_26 1
+	create_makefile 1
 
 	# Check and generate a correct version.h file
 	generate_sources_version
@@ -1162,8 +873,7 @@ function main_global ()
 
 
 	# Configure, check and build the driver
-	[ $KERNEL_FAMILY == "2.4" ] && make_driver_24
-	[ $KERNEL_FAMILY == "2.6" ] && make_driver_26 1
+	make_driver 1
 
 	# Copy driver
 	copy_driver
@@ -1175,11 +885,10 @@ function main_global ()
 #####################################################################
 
 drv_name=`echo sk98lin`
-VERSION=`echo "10.61.3.3 (Jul-07-2008)"`
+VERSION=`echo "10.70.1.3 (Jun-30-2008)"`
 #drv_name=`echo sk98lin`
 working_dir=`pwd`
 logfile="$working_dir/install.log"
-rm -rf $logfile &> /dev/null
 trap cleanup_trap INT TERM
 KERNEL_TREE_MAKE=0;
 ALT_OPTION_FLAG=0
