@@ -411,7 +411,6 @@ struct  pt_regs *ptregs)  /* not used by our driver                      */
 		SK_DBG_MSG(pAC, SK_DBGMOD_DRV, SK_DBGCAT_DRV_INT_SRC,
 			("No Interrupt\n ==> SkY2Isr\n"));
 		return SkIsrRetNone;
-
 	}
 
 #ifdef Y2_RECOVERY
@@ -425,9 +424,13 @@ struct  pt_regs *ptregs)  /* not used by our driver                      */
 
 #ifdef CONFIG_SK98LIN_NAPI
 	/* Since both boards share one irq, they share one poll routine */
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,23)
+	napi_schedule(&pNet->napi);
+#else
 	if (__netif_rx_schedule_prep(pAC->dev[0])) {
 		__netif_rx_schedule(pAC->dev[0]);
 	}
+#endif
 #else
 	handledStatLE = HandleStatusLEs(pAC);
 
@@ -656,20 +659,29 @@ struct SK_NET_DEVICE *dev)  /* via which device?        */
  *	The slowpath lock needs to be set because HW accesses may
  *	interfere with slowpath events (e.g. TWSI)
  */
-int SkY2Poll(
-struct net_device *dev,     /* device that needs to be polled */
-int               *budget)  /* how many budget do we have?    */
-{
-	DEV_NET       *pNet         = (DEV_NET*) dev->priv;
-	SK_AC	      *pAC          = pNet->pAC;
-	int           WorkToDo      = min(*budget, dev->quota);
-	int           WorkDone      = 0;
-	SK_BOOL       handledStatLE = SK_FALSE;
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,23)
+int SkY2Poll(struct napi_struct *napi, int WorkToDo) {
+#else
+int SkY2Poll(struct net_device *dev, int *budget) {
+#endif
+
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,23)
+	DEV_NET	*pNet		= container_of(napi, DEV_NET, napi);
+	SK_AC	*pAC		= pNet->pAC;
+#else
+	DEV_NET	*pNet		= (DEV_NET*) dev->priv;
+	SK_AC	*pAC		= pNet->pAC;
+	int	WorkToDo	= min(*budget, dev->quota);
+#endif
+	int	WorkDone	= 0;
+	SK_BOOL	handledStatLE	= SK_FALSE;
 
 	handledStatLE = HandleStatusLEs(pAC, &WorkDone, WorkToDo);
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24)
 	*budget -= WorkDone;
 	dev->quota -= WorkDone;
+#endif
 
 	/* 
 	** Check for Special Interrupts 
@@ -691,8 +703,9 @@ int               *budget)  /* how many budget do we have?    */
 	}
 
 	if(WorkDone < WorkToDo) {
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24)
 		netif_rx_complete(dev);
-
+#endif
 		/*
 		** Stop and restart TX timer in case a Status LE was handled
 		*/
@@ -700,6 +713,9 @@ int               *budget)  /* how many budget do we have?    */
 			SK_OUT8(pAC->IoBase, STAT_TX_TIMER_CTRL, TIM_STOP);
 			SK_OUT8(pAC->IoBase, STAT_TX_TIMER_CTRL, TIM_START);
 		}
+#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,23)
+		napi_complete(napi);
+#endif
 
 		/* 
 		** Reenable interrupts
